@@ -179,7 +179,7 @@ class GitLibMixin:
 
         oid = self._repo.create_blob(data)
         self.prepareWorkingBranch()
-        self.__index.add(pygit2.IndexEntry(path, oid, mode))
+        self.__index.add(pygit2.IndexEntry(Path(path).as_posix(), oid, mode))
         self.__isIndexDirty = True
 
     def _moveDirectory(self, fromPath: Path, toPath: Path):
